@@ -1,3 +1,18 @@
+
+function minimize(e,box,max,min){
+  box.classList.remove("panzoom-fullscreen");
+  max.classList.remove("panzoom-hidden");
+  min.classList.add("panzoom-hidden");
+}
+
+function escapeFullScreen(e,box,max,min) {
+  console.log(e,box,);
+  
+  if (e.keyCode == 27){
+    minimize(e,box,max,min);
+  }
+}
+
 function add_buttons(box, instance) {
   let reset = box.querySelector(".panzoom-reset");
   let max = box.querySelector(".panzoom-max");
@@ -9,22 +24,26 @@ function add_buttons(box, instance) {
     instance.moveTo(0, 0);
     instance.zoomAbs(0, 0, 1);
   });
-  info.addEventListener("click", function (e) {
-    // console.log(box);
-    if (box.dataset.info == "true") {
-      box.dataset.info = false;
-      info_box.classList.add("panzoom-hidden");
-    } else {
-      box.dataset.info = true;
-      info_box.classList.remove("panzoom-hidden");
-    }
-  });
+  if (info!=undefined){
+    info.addEventListener("click", function (e) {
+      // console.log(box);
+      if (box.dataset.info == "true") {
+        box.dataset.info = false;
+        info_box.classList.add("panzoom-hidden");
+      } else {
+        box.dataset.info = true;
+        info_box.classList.remove("panzoom-hidden");
+      }
+    });
+  }
   if (max != undefined) {
     max.addEventListener("click", function (e) {
       //instance.setTransformOrigin({ x: 0.25, y: 0.25 });
+      // box.addEventListener("keydown", escapeFullScreen(e,box,max,min))
       box.classList.add("panzoom-fullscreen");
       min.classList.remove("panzoom-hidden");
       max.classList.add("panzoom-hidden");
+      box.focus();
     });
   }
   if (min != undefined) {
@@ -34,6 +53,9 @@ function add_buttons(box, instance) {
       min.classList.add("panzoom-hidden");
     });
   }
+  box.addEventListener("keydown",function(e){
+    escapeFullScreen(e,box,max,min);
+  });
 }
 
 function activate_zoom_pan() {
@@ -68,6 +90,7 @@ function activate_zoom_pan() {
           var shouldIgnore = !e.altKey && !e.button == 1;
           return shouldIgnore;
         },
+        zoomDoubleClickSpeed: 1,
       });
       add_buttons(box, instance);
     }
